PEP: 254 Title: Making Classes Look More Like Types Version: $Revision$
Last-Modified: $Date$ Author: guido\@python.org (Guido van Rossum)
Status: Rejected Type: Standards Track Content-Type: text/x-rst Created:
18-June-2001 Python-Version: 2.2 Post-History:

Abstract
========

This PEP has not been written yet. Watch this space!

Status
======

This PEP was a stub entry and eventually abandoned without having been
filled-out. Substantially most of the intended functionality was
implemented in Py2.2 with new-style types and classes.

Copyright
=========

This document has been placed in the public domain.

.. Local Variables: mode: indented-text indent-tabs-mode: nil End:
